Salut à Toi: Contrat Social

Le projet « Salut à Toi » est né d'un besoin de protection de nos libertés, de notre vie privée et de notre indépendance. Il se veut garant des droits et libertés qu'un utilisateur a vis à vis de ses propres informations, des informations numériques sur sa vie ou celles de ses connaissances, des données qu'il manipule; et se veut également un point de contact humain, ne se substituant pas aux rapports réels, mais au contraire les facilitant.
Salut à Toi lutte et luttera toujours contre toute forme de main mise sur les technologies par des intérêts privés. Le réseau global doit appartenir à tous, et être un point d'expression et de liberté pour l'Humanité.
À ce titre, « Salut à Toi » et ceux qui y participent se basent sur un contrat social, un engagement vis à vis de ceux qui l'utilisent. Ce contrat consiste en les points suivants:

- nous plaçons la Liberté en tête de nos priorités: liberté de l'utilisateur, liberté vis à vis de ses données. Pour cela, « Salut à Toi » est un logiciel Libre - condition essentielle -, et son infrastructure se base également sur des logiciels Libres, c'est à dire des logiciels qui respectent ces 4 libertés fondamentales
  - la liberté d'exécuter le programme, pour tous les usages,
  - la liberté d'étudier le fonctionnement du programme et de l'adapter à ses besoins,
  - la liberté de redistribuer des copies du programme,
  - la liberté d'améliorer le programme et de distribuer ces améliorations au public.
Vous avez ainsi la possibilité d'installer votre propre version de « Salut à Toi » sur votre propre machine, d'en vérifier - et de comprendre - ainsi son fonctionnement, de l'adapter à vos besoins, d'en faire profiter vos amis.
- Les informations vous concernant vous appartiennent, et nous n'aurons pas la prétention - et l'indécence ! - de considérer le contenu que vous produisez ou faites circuler via « Salut à Toi » comme nous appartenant. De même, nous nous engageons à ne jamais faire de profit en revendant vos informations personnelles.
- Nous incitons fortement à la décentralisation généralisée. « Salut à Toi » étant basé sur un protocole décentralisé (XMPP), il l'est lui-même par nature. La décentralisation est essentielle pour une meilleure protection de vos informations, une meilleure résistance à la censure ou aux pannes, et pour éviter les dérives autoritaires.
- Luttant contre les tentatives de contrôle privé et les abus commerciaux du réseau global, et afin de garder notre indépendance, nous nous refusons à toute forme de publicité: vous ne verrez jamais de forme de réclame commerciale de notre fait.
- L'Égalité des utilisateurs est essentielle pour nous, nous refusons toute forme de discrimination, que ce soit pour une zone géographique, une catégorie de la population, ou tout autre raison.
- Nous ferons tout notre possible pour lutter contre toute tentative de censure. Le réseau global doit être un moyen d'expression pour tous.
- Nous refusons toute idée d'autorité absolue en ce qui concerne les décisions prises pour « Salut à Toi » et son fonctionnement, et le choix de la décentralisation et l'utilisation de logiciel Libre permet de lutter contre toute forme de hiérarchie.
- L'idée de Fraternité est essentielle, aussi:
  - nous ferons notre possible pour aider les utilisateurs, quel que soit leur niveau
  - de même, des efforts seront fait quant à l'accessibilité pour tous
  - « Salut à Toi », XMPP, et les technologies utilisées facilitent les échanges électroniques, mais nous désirons mettre l'accent sur les rencontres réelles et humaines: nous favoriserons toujours le réel sur le virtuel.